@@ -30,7 +30,7 @@
 #endif
 
 #include "ksignalplotter_p.h"
-#include "processcore/processcore_debug.h"
+#include "ksignalplotter_debug.h"
 
 #include <QPainter>
 #include <QPixmap>
@@ -93,10 +93,9 @@ void KSignalPlotter::setUnit(const KLocalizedString &unit) {
 
 void KSignalPlotter::addBeam( const QColor &color )
 {
-    QList< QList<qreal> >::Iterator it;
     //When we add a new beam, go back and set the data for this beam to NaN for all the other times, to pad it out.
     //This is because it makes it easier for moveSensors
-    for(it = d->mBeamData.begin(); it != d->mBeamData.end(); ++it) {
+    for(QList< QList<qreal> >::Iterator it = d->mBeamData.begin(), total = d->mBeamData.end(); it != total; ++it) {
         (*it).append( std::numeric_limits<qreal>::quiet_NaN() );
     }
     d->mBeamColors.append(color);
@@ -109,11 +108,11 @@ QColor KSignalPlotter::beamColor( int index ) const {
 
 void KSignalPlotter::setBeamColor( int index, const QColor &color ) {
     if(!color.isValid()) {
-        qCDebug(LIBKSYSGUARD) << "Invalid color";
+        qCDebug(LIBKSYSGUARD_KSIGNALPLOTTER) << "Invalid color";
         return;
     }
     if( index >= d->mBeamColors.count() ) {
-        qCDebug(LIBKSYSGUARD) << "Invalid index" << index;
+        qCDebug(LIBKSYSGUARD_KSIGNALPLOTTER) << "Invalid index" << index;
         return;
     }
     Q_ASSERT(d->mBeamColors.count() == d->mBeamColorsLight.count());
@@ -515,7 +514,7 @@ void KSignalPlotterPrivate::rescale() {
 void KSignalPlotterPrivate::addSample( const QList<qreal>& sampleBuf )
 {
     if(sampleBuf.count() != mBeamColors.count()) {
-        qCDebug(LIBKSYSGUARD) << "Sample data discarded - contains wrong number of beams";
+        qCDebug(LIBKSYSGUARD_KSIGNALPLOTTER) << "Sample data discarded - contains wrong number of beams";
         return;
     }
     mBeamData.prepend(sampleBuf);
@@ -551,7 +550,7 @@ void KSignalPlotterPrivate::reorderBeams( const QList<int>& newOrder )
     QList< QList<qreal> >::Iterator it;
     for(it = mBeamData.begin(); it != mBeamData.end(); ++it) {
         if(newOrder.count() != (*it).count()) {
-            qCWarning(LIBKSYSGUARD) << "Serious problem in move sample.  beamdata[i] has " << (*it).count() << " and neworder has " << newOrder.count();
+            qCWarning(LIBKSYSGUARD_KSIGNALPLOTTER) << "Serious problem in move sample.  beamdata[i] has " << (*it).count() << " and neworder has " << newOrder.count();
         } else {
             QList<qreal> newBeam;
             for(int i = 0; i < newOrder.count(); i++) {
